/**
 *  Copyright (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  Licensed under the GPL, Version 3.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *       http://www.gnu.org/licenses/gpl.html
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 * --------------------------------------------------------------------------
 *  版权 (c) 1997-2013, tinygroup.org (luo_guo@live.cn).
 *
 *  本开源软件遵循 GPL 3.0 协议;
 *  如果您不遵循此协议，则不被允许使用此文件。
 *  你可以从下面的地址获取完整的协议文本
 *
 *       http://www.gnu.org/licenses/gpl.html
 */
package org.tinygroup.uiengine.config;

import com.thoughtworks.xstream.annotations.XStreamAlias;
import com.thoughtworks.xstream.annotations.XStreamAsAttribute;

/**
 * 定义UI组件
 * 
 * @author luoguo
 * 
 */
@XStreamAlias("ui-component")
public class UIComponent implements Comparable<UIComponent> {
	@XStreamAsAttribute
	private String name;
	@XStreamAsAttribute
	private String title;
	@XStreamAsAttribute
	private String category;
	@XStreamAsAttribute
	private String icon;
	@XStreamAsAttribute
	private int order;
	private String description;
	@XStreamAsAttribute
	private String help;
	@XStreamAsAttribute
	private String dependencies;// 依赖哪些，如果依赖多个，用","分隔
	@XStreamAlias("css-resource")
	private String cssResource;
	@XStreamAlias("js-resource")
	private String jsResource;
	@XStreamAlias("css-debug-resource")
	private String cssDebugResource;
	@XStreamAlias("js-debug-resource")
	private String jsDebugResource;
	@XStreamAlias("css-codelet")
	private String cssCodelet;
	@XStreamAlias("js-codelet")
	private String jsCodelet;
	private Macros macros;
	private transient boolean health;
	private transient boolean computed = false;

	public Macros getMacros() {
		return macros;
	}

	public void setMacros(Macros macros) {
		this.macros = macros;
	}

	public boolean isComputed() {
		return computed;
	}

	public void setComputed(boolean computed) {
		this.computed = computed;
	}

	public boolean isHealth() {
		return health;
	}

	public void setHealth(boolean health) {
		this.health = health;
	}

	public String getDependencies() {
		return dependencies;
	}

	public void setDependencies(String dependencies) {
		this.dependencies = dependencies;
	}

	public int getOrder() {
		return order;
	}

	public void setOrder(int order) {
		this.order = order;
	}

	public String getHelp() {
		return getInfo(help);
	}

	public void setHelp(String help) {
		this.help = help;
	}

	public String getCategory() {
		return getInfo(category);
	}

	public void setCategory(String category) {
		this.category = category;
	}

	public String getCssDebugResource() {
		return cssDebugResource;
	}

	public void setCssDebugResource(String cssDebugResource) {
		this.cssDebugResource = cssDebugResource;
	}

	public String getJsDebugResource() {
		return jsDebugResource;
	}

	public void setJsDebugResource(String jsDebugResource) {
		this.jsDebugResource = jsDebugResource;
	}

	public String getCssResource() {
		return getInfo(cssResource);
	}

	private String getInfo(String str) {
		if (str != null) {
			String string = str.trim();
			if (string.length() == 0) {
				string = null;
			}
			return string;
		}
		return null;
	}

	public void setCssResource(String cssResource) {
		this.cssResource = cssResource;
	}

	public String getJsResource() {
		return getInfo(jsResource);
	}

	public void setJsResource(String jsResource) {
		this.jsResource = jsResource;
	}

	public String getCssCodelet() {
		return getInfo(cssCodelet);
	}

	public void setCssCodelet(String cssCodelet) {
		this.cssCodelet = cssCodelet;
	}

	public String getJsCodelet() {
		return getInfo(jsCodelet);
	}

	public String getName() {
		return getInfo(name);
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getTitle() {
		return getInfo(title);
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public String getIcon() {
		return getInfo(icon);
	}

	public void setIcon(String icon) {
		this.icon = icon;
	}

	public String getDescription() {
		return getInfo(description);
	}

	public void setDescription(String description) {
		this.description = description;
	}

	public void setJsCodelet(String jsCodelet) {
		this.jsCodelet = jsCodelet;
	}

	public int compareTo(UIComponent o) {
		if (order > o.order)
			return -1;
		if (order < o.order)
			return 1;

		return o.getName().compareTo(name);
	}
}
